Description Usage Arguments Value Examples
View source: R/dangeo_get_data.R
Function for downloading geodata from kortforsyningen.dk
1 2 3 4 5 6 7 8 |
ftp_folder |
Name of the ftp folder |
zip_name |
Name of the zip file we would like to download.. |
out_folder |
Name of the local folder where the data will be saved (by default it is set to the results of rappdirs::user_cache_dir()). |
userpwd |
Username and Password (format = USERNAME:PASSWORD). |
overwrite |
Overwrite previous files (by default overwrite = FALSE) |
unzip |
Logical parameter indication if the file should be unzipped (TRUE) or not (FALSE) |
Data from https://download.kortforsyningen.dk/content/geodataprodukter.
1 2 3 4 5 6 7 8 | library(dangeo)
# Set username, password, and local directory
dangeo_set_param()
# Download data
dangeo_get_data(ftp_folder = "CORINE",
zip_name = "DK_CORINE_SHP_UTM32-WGS84.zip")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.